@@ -1,5 +1,5 @@
 require 'rabbit/element/slide-element'
-require 'rabbit/element/text-container-element'
+require 'rabbit/element/text-block-element'
 
 module Rabbit
   module Element
