@@ -35,8 +35,7 @@ module Rabbit
       end
 
       def pixbuf
-        ensure_update
-        internal_pixbuf
+        @pixbuf
       end
 
       def resize(w, h)
@@ -61,7 +60,11 @@ module Rabbit
       end
 
       def draw(canvas, x, y, params={})
-        canvas.draw_pixbuf(pixbuf, x, y, params)
+        default_params = {
+          :width => width,
+          :height => height,
+        }
+        canvas.draw_pixbuf(pixbuf, x, y, default_params.merge(params))
       end
 
       private
@@ -96,17 +99,6 @@ module Rabbit
         loader.signal_handler_disconnect(id)
         loader
       end
-
-      def ensure_update
-        _pixbuf = internal_pixbuf
-        if _pixbuf.nil? or [@width, @height] != [_pixbuf.width, _pixbuf.height]
-          ensure_resize(@width, @height)
-        end
-      end
-
-      def internal_pixbuf
-        @pixbuf
-      end
     end
   end
 end
