@@ -7,22 +7,29 @@ require "rabbit/image/base"
 module Rabbit
   module ImageManipulable
     class PDF < Base
+      include GetText
 
       unshift_loader(self)
 
       class << self
         def match?(filename)
-          File.open(filename) do |f|
-            line = f.gets
-            line and /\A%PDF-1\.\d\z/ =~ line.chomp
+          return true if File.extname(filename) == ".pdf"
+
+          File.open(filename) do |file|
+            line = file.gets
+            return false if line.nil?
+
+            begin
+              /\A%PDF-1\.\d\z/ =~ line.chomp
+            rescue ArgumentError
+              false
+            end
           end
-        rescue ArgumentError
-          false
         end
       end
 
       def draw(canvas, x, y, params={})
-        if @doc and canvas.poppler_available?
+        if @document and canvas.poppler_available?
           default_params = {
             :width => width,
             :height => height,
@@ -39,21 +46,23 @@ module Rabbit
 
       private
       def page
-        index = self["page"] || 0
+        index = self["page"] || 1
         begin
           index = Integer(index)
         rescue ArgumentError
+          message = _("invalid PDF page number: <%s>") % index.inspect
+          raise ImageLoadError.new("#{@filename}: #{message}")
         end
-        _page = @doc[index]
+        _page = @document[index - 1]
         if _page.nil?
-          message = _("%s page isn't exist in PDF") % index.inspect
+          message = _("%s page doesn't exist in PDF") % index
           raise ImageLoadError.new("#{@filename}: #{message}")
         end
         _page
       end
 
       def update_size
-        @doc = Poppler::Document.new(uri)
+        @document = Poppler::Document.new(uri)
         @width, @height = page.size
       end
 
