@@ -21,19 +21,21 @@ module Rabbit
 
       def draw(canvas, x, y, params={})
         if @handle and canvas.rsvg_available?
-          params["width"] ||= @width
-          params["height"] ||= @height
-          canvas.draw_rsvg_handle(@handle, x, y, params)
+          default_params = {
+            :width => width,
+            :height => height,
+          }
+          canvas.draw_rsvg_handle(@handle, x, y, default_params.merge(params))
         else
           super
         end
       end
 
-      private
-      def ensure_resize(w, h)
-        @pixbuf = to_pixbuf(w, h)
+      def pixbuf
+        @pixbuf ||= to_pixbuf(width, height)
       end
 
+      private
       def update_size
         @handle = nil
         rsvg_environment do |name|
@@ -43,9 +45,9 @@ module Rabbit
             @width = dim.width
             @height = dim.height
           else
-            _pixbuf = RSVG.pixbuf_from_file(name)
-            @width = _pixbuf.width
-            @height = _pixbuf.height
+            @pixbuf = RSVG.pixbuf_from_file(name)
+            @width = @pixbuf.width
+            @height = @pixbuf.height
           end
         end
       end
