@@ -25,7 +25,7 @@ module Rabbit
           @info_window.hide
         end
 
-        def post_move(index)
+        def post_move(old_index, index)
           super
           @info_window.moved(index)
         end
