@@ -76,14 +76,14 @@ module Rabbit
             mod = mod.inject(no_mod) do |result, item|
               result | item
             end
-            keys = (0..9).collect{|i| Gdk::Keyval.const_get("GDK_#{i}")}
+            keys = (0..9).collect{|i| Gdk::Keyval.const_get("GDK_KEY_#{i}")}
             set_keys(keys, mod) do |group, obj, val, modifier|
-              index = calc_slide_number(val - Gdk::Keyval::GDK_0, modifier)
+              index = calc_slide_number(val - Gdk::Keyval::GDK_KEY_0, modifier)
               @canvas.activate("JumpTo") {index}
             end
-            keys = (0..9).collect{|i| Gdk::Keyval.const_get("GDK_KP_#{i}")}
+            keys = (0..9).collect{|i| Gdk::Keyval.const_get("GDK_KEY_KP_#{i}")}
             set_keys(keys, mod) do |group, obj, val, modifier|
-              index = calc_slide_number(val - Gdk::Keyval::GDK_KP_0, modifier)
+              index = calc_slide_number(val - Gdk::Keyval::GDK_KEY_KP_0, modifier)
               @canvas.activate("JumpTo") {index}
             end
           end
@@ -136,10 +136,6 @@ module Rabbit
           set_keys(keys, mod) do |group, obj, val, modifier|
             @canvas.activate("CacheAllSlides")
           end
-          keys = Keys::TOGGLE_COMMENT_FRAME_KEYS
-          set_keys(keys, mod) do |group, obj, val, modifier|
-            @canvas.activate("ToggleCommentFrame")
-          end
           keys = Keys::SEARCH_SLIDE_FORWARD_KEYS
           set_keys(keys, mod) do |group, obj, val, modifier|
             @canvas.activate("SearchSlideForward")
@@ -169,10 +165,6 @@ module Rabbit
           set_keys(keys, mod) do |group, obj, val, modifier|
             @canvas.activate("ToggleBlackout")
           end
-          keys = Keys::Shift::TOGGLE_COMMENT_VIEW_KEYS
-          set_keys(keys, mod) do |group, obj, val, modifier|
-            @canvas.activate("ToggleCommentView")
-          end
           keys = Keys::Shift::EXPAND_HOLE_KEYS
           set_keys(keys, mod) do |group, obj, val, modifier|
             @canvas.activate("ExpandHole")
@@ -262,16 +254,16 @@ module Rabbit
 
         def set_key_press_event(widget)
           prev_keys = [
-            Gdk::Keyval::GDK_Up,
-            Gdk::Keyval::GDK_Left,
-            Gdk::Keyval::GDK_KP_Up,
-            Gdk::Keyval::GDK_KP_Left,
+            Gdk::Keyval::GDK_KEY_Up,
+            Gdk::Keyval::GDK_KEY_Left,
+            Gdk::Keyval::GDK_KEY_KP_Up,
+            Gdk::Keyval::GDK_KEY_KP_Left,
           ]
           next_keys = [
-            Gdk::Keyval::GDK_Right,
-            Gdk::Keyval::GDK_Down,
-            Gdk::Keyval::GDK_KP_Right,
-            Gdk::Keyval::GDK_KP_Down,
+            Gdk::Keyval::GDK_KEY_Right,
+            Gdk::Keyval::GDK_KEY_Down,
+            Gdk::Keyval::GDK_KEY_KP_Right,
+            Gdk::Keyval::GDK_KEY_KP_Down,
           ]
           widget.signal_connect("key_press_event") do |_widget, event|
             handled = true
