@@ -251,25 +251,51 @@ module Rabbit
 
         def draw_pixbuf(pixbuf, x, y, params={})
           x, y = from_screen(x, y)
+          @context.save do
+            @context.translate(x, y)
+            set_source_pixbuf(pixbuf, params)
+            @context.paint(params[:alpha])
+          end
 
+          _draw_reflected_pixbuf(pixbuf, x, y, params)
+        end
+
+        def set_source_pixbuf(pixbuf, params)
           draw_scaled_pixbuf = params[:draw_scaled_pixbuf]
           draw_scaled_pixbuf = @draw_scaled_image if draw_scaled_pixbuf.nil?
           width = (params[:width] || pixbuf.width).to_f
           height = (params[:height] || pixbuf.height).to_f
-          if draw_scaled_pixbuf and
-              [width, height] != [pixbuf.width, pixbuf.height]
-            pixbuf = pixbuf.scale(width, height)
-          end
-          @context.save do
-            @context.translate(x, y)
-            unless draw_scaled_pixbuf
-              @context.scale(width / pixbuf.width, height / pixbuf.height)
-            end
+
+          if [width, height] == [pixbuf.width, pixbuf.height]
             @context.set_source_pixbuf(pixbuf, 0, 0)
-            @context.paint(params[:alpha])
+            return
           end
 
-          _draw_reflected_pixbuf(pixbuf, x, y, params[:reflect])
+          case draw_scaled_pixbuf
+          when true
+            scaled_pixbuf = pixbuf.scale(width, height)
+            @context.set_source_pixbuf(scaled_pixbuf, 0, 0)
+          when false
+            @context.set_source_pixbuf(pixbuf, 0, 0)
+            matrix = ::Cairo::Matrix.scale(pixbuf.width / width,
+                                           pixbuf.height / height)
+            @context.source.matrix = matrix
+          else
+            scales = [4, 3, 2]
+            scales.each do |scale|
+              if width * scale < pixbuf.width and height * scale < pixbuf.height
+                scaled_pixbuf = pixbuf.scale(width * scale, height * scale)
+                @context.set_source_pixbuf(scaled_pixbuf)
+                matrix = ::Cairo::Matrix.scale(scale, scale)
+                @context.source.matrix = matrix
+                return
+              end
+            end
+            @context.set_source_pixbuf(pixbuf, 0, 0)
+            matrix = ::Cairo::Matrix.scale(pixbuf.width / width,
+                                           pixbuf.height / height)
+            @context.source.matrix = matrix
+          end
         end
 
         def rsvg_available?
@@ -291,7 +317,7 @@ module Rabbit
           end
 
           _draw_reflected_rsvg_handle(handle, x, y, width, height,
-                                      params[:reflect])
+                                      params)
         end
 
         def poppler_available?
@@ -436,18 +462,19 @@ module Rabbit
         end
 
         def _draw_reflected_pixbuf(pixbuf, x, y, params)
-          return unless params
+          reflect_params = params[:reflect]
+          return unless reflect_params
 
-          params = {} if params == true
-          ratio = params[:ratio] || 0.3
-          start_alpha = params[:start_alpha] || 0.3
+          reflect_params = {} if reflect_params == true
+          ratio = reflect_params[:ratio] || 0.3
+          start_alpha = reflect_params[:start_alpha] || 0.3
 
           @context.save do
-            width = pixbuf.width
-            height = pixbuf.height
+            width = (params[:width] || pixbuf.width).to_f
+            height = (params[:height] || pixbuf.height).to_f
             @context.translate(x, y + height * 2)
             reflect_context(:x)
-            @context.set_source_pixbuf(pixbuf, 0, 0)
+            set_source_pixbuf(pixbuf, params)
             pattern = ::Cairo::LinearPattern.new(width * 0.5, 0,
                                                  width * 0.5, height)
             pattern.add_color_stop_rgba(0, 0, 0, 0, 0)
