@@ -217,6 +217,7 @@ module Rabbit
       include Element
       include Searcher
       include DirtyCount
+      include GetText
 
       extend Forwardable
 
@@ -394,7 +395,7 @@ module Rabbit
       end
 
       def font_families
-        canvas.font_families.collect{|x| x.name}
+        canvas.font_families.collect {|family| family.name}
       end
 
       def find_font_family(target_name)
@@ -617,6 +618,14 @@ module Rabbit
         Parser::Ext::Entity::TABLE[key]
       end
 
+      def image_element(path, properties={})
+        image = Parser::Ext::Image.make_image(canvas, path, properties)
+        if image.nil?
+          raise ImageFileDoesNotExistError.new(path)
+        end
+        image
+      end
+
       def base_directory
         canvas.full_path(".")
       end
