@@ -25,13 +25,13 @@ end
 match(TitleSlide, ContentSource) do |sources|
   sources.prop_set("size", @title_slide_content_source_font_size)
   sources.prop_set("style", "italic")
-
-  sources.margin_bottom = @space
 end
 
 match(TitleSlide, Institution) do |institutions|
   institutions.prop_set("size", @title_slide_institution_font_size)
   institutions.prop_set("style", "italic")
+
+  institutions.margin_bottom = @space
 end
 
 match(TitleSlide, Place) do |places|
