@@ -20,7 +20,7 @@ end
 
 @image_timer_auto_scroll_direction ||= :left
 
-@image_timer_image ||= "kame.png"
+@image_timer_image ||= "mini-kame-taro.png"
 @image_timer_interval ||= 5
 @image_timer_space_ratio ||= 1.0 / 12.0
 
