@@ -1,3 +1,5 @@
+require "pathname"
+
 require 'rabbit/theme/entry'
 
 module Rabbit
@@ -41,17 +43,25 @@ module Rabbit
       end
 
       def find_theme(theme_name=name, only_image=false)
+        if theme_name == "."
+          if only_image
+            entry = ImageDirectoryEntry.new(@logger, ".", ".")
+          else
+            entry = DirectoryEntry.new(@logger, ".", ".")
+          end
+          return entry if entry.available?
+        end
+
+        unless only_image
+          entry = FileEntry.new(@logger, base_directory, theme_name)
+          return entry if entry.available?
+        end
+
         if only_image
           collector = "collect_image_theme"
         else
           collector = "collect_all_theme"
         end
-
-        unless only_image
-          entry = SingleFileEntry.new(base_directory, theme_name)
-          return entry if entry.available?
-        end
-
         found_entry = nil
         __send__(collector) do |entry|
           if theme_name == entry.name
@@ -60,11 +70,21 @@ module Rabbit
           end
         end
 
-        raise LoadError, "can't find theme: #{theme_name}." if found_entry.nil?
+        if found_entry.nil?
+          if only_image
+            entry = ImageGemEntry.new(@logger, theme_name)
+          else
+            entry = GemEntry.new(@logger, theme_name)
+          end
+          return entry if entry.available?
+          raise LoadError, "can't find theme: #{theme_name}."
+        end
+
         found_entry
       end
 
       def find_file(target, themes=nil)
+        return target if absolute_path?(target)
         themes ||= @theme_stack + @image_entries
         found_entry = themes.find do |entry|
           entry.have_file?(target)
@@ -77,6 +97,10 @@ module Rabbit
         found_entry.full_path(target)
       end
 
+      def absolute_path?(path)
+        Pathname.new(path).absolute?
+      end
+
       def collect_all_theme(&block)
         theme_names = {}
         themes = []
@@ -93,11 +117,12 @@ module Rabbit
       end
 
       def collect_theme(&block)
-        _collect_theme(theme_load_path, DirectoryEntry, &block)
+        _collect_theme(theme_load_path, [FileEntry, DirectoryEntry], &block)
       end
 
       def collect_image_theme(&block)
-        _collect_theme(image_load_path, ImageDirectoryEntry, "image_dir", &block)
+        _collect_theme(image_load_path, [ImageFileEntry, ImageDirectoryEntry],
+                       "image_dir", &block)
       end
 
       def theme_load_path
@@ -108,21 +133,25 @@ module Rabbit
         Config::IMAGE_PATH + $LOAD_PATH
       end
 
-      def _collect_theme(path, entry_class, converter=nil, &block)
+      def _collect_theme(path, entry_classes, converter=nil, &block)
         converter ||= "theme_dir"
         themes = []
-        theme_name = {}
+        theme_names = {}
         path.each do |dir|
           base_name = __send__(converter, dir)
           if File.directory?(base_name)
             Dir.foreach(base_name) do |theme|
               next if /\A..?\z/ =~ theme
-              file = File.join(File.expand_path(base_name), theme)
-              entry = entry_class.new(file)
-              if entry.available? and !theme_name.has_key?(theme)
-                block.call(entry) if block
-                themes << entry
-                theme_name[theme] = true
+              next if theme_names.has_key?(theme)
+              theme_dir = File.join(File.expand_path(base_name), theme)
+              entry_classes.each do |entry_class|
+                entry = entry_class.new(@logger, theme_dir, theme)
+                if entry.available?
+                  block.call(entry) if block
+                  themes << entry
+                  theme_names[theme] = true
+                  break
+                end
               end
             end
           end
