@@ -29,12 +29,30 @@ theme_exit if @syntax_highlighting_uninstall
   :reserved => {
     :color => "#204a87",
   },
+  :keyword => {
+    :color => "#204a87",
+  },
   :method => {
     :color => "#000000",
   },
-  :string => {
+  :constant => {
     :color => "#4e9a06",
   },
+  :string => {
+    :color => "#a40000",
+  },
+  :delimiter => {
+    :color => "#ef2929",
+  },
+  :content => {
+    :color => "#a40000",
+  },
+  :symbol => {
+    :color => "#4e9a06",
+  },
+  :integer => {
+    :color => "#c4a000",
+  },
   :variable => {
     :color => "#ce5c00",
   },
@@ -62,6 +80,9 @@ theme_exit if @syntax_highlighting_uninstall
   :pre_type => {
     :color => "#5c35cc",
   },
+  :predefined_type => {
+    :color => "#5c35cc",
+  },
   :directive => {
     :color => "#5c35cc",
   },
