@@ -33,6 +33,8 @@ match("**", CustomTag) do |tags|
 
   tags.each do |tag|
     case tag.name
+    when "left"
+      find_outer_block.call(tag).align = "left"
     when "center"
       find_outer_block.call(tag).horizontal_centering = true
     when "right"
@@ -45,10 +47,14 @@ match("**", CustomTag) do |tags|
       find_target.call(tag).prop_set("size", @large_font_size)
     when "x-large"
       find_target.call(tag).prop_set("size", @x_large_font_size)
-    when "margin-top"
-      find_outer_block.call(tag).margin_top += @space
-    when "margin-bottom"
-      find_outer_block.call(tag).margin_bottom += @space
+    when /\A(normal|oblique|italic)\z/
+      find_target.call(tag).prop_set("style", $1)
+    when /\Amargin-(top|bottom|left|right)(?:\s*\*\s*(\d+))?\z/
+      target = "margin_#{$1}"
+      scale = Integer($2 || 1)
+      outer_block = find_outer_block.call(tag)
+      current_value = outer_block.send(target)
+      outer_block.send("#{target}=", current_value + (@space * scale))
     else
       handler = find_handler.call(tag)
       if handler
